package com.red;

import java.io.Reader;
import java.sql.SQLException;
import java.util.List;

import com.ibatis.common.resources.Resources;
import com.ibatis.sqlmap.client.SqlMapClient;
import com.ibatis.sqlmap.client.SqlMapClientBuilder;

public class IStudentDAOImpl implements IStudentDAO {

	private static SqlMapClient sqlMapClient=null;
	static{
		try{
		Reader reader=Resources.getResourceAsReader("com/red/SqlMapConfig.xml");
		sqlMapClient = SqlMapClientBuilder.buildSqlMapClient(reader);
		reader.close();
	}catch (Exception e) {
		e.printStackTrace();
	}
	}
	
	public void addStudent(Student student) {
		try {
			sqlMapClient.insert("insertStudent", student);
		} catch (SQLException e) {
			e.printStackTrace();
		}

	}

	public void deleteStudentById(int id) {
		try {
			sqlMapClient.delete("deleteStudentById",id);
		} catch (SQLException e) {
			e.printStackTrace();
		}
	}

	public List<Student> queryAllStudent() {
		List<Student> 	studentList=null;;
		try {
			studentList=sqlMapClient.queryForList("selectAllStudent");
		} catch (SQLException e) {
			e.printStackTrace();
		}
		return studentList;
	}

	public Student queryStudentById(int id) {
		Student student=null;
		try {
			student=(Student) sqlMapClient.queryForObject("selectStudentById",id);
		} catch (SQLException e) {
			e.printStackTrace();
		}
		return student;
	}

	/**
	 * 模糊查询
	 */
	public List<Student> queryStudentByName(String name) {
		List<Student> studentList=null;
		try {
			studentList=sqlMapClient.queryForList("selectStudentByName", name);
		} catch (SQLException e) {
			e.printStackTrace();
		}
		return studentList;
	}

	public void updateStudentById(Student student) {
		try {
			sqlMapClient.update("updateStudentById", student);
		} catch (SQLException e) {
			e.printStackTrace();
		}
		
	}

	public static void main(String[] args) {
		IStudentDAO dao=new IStudentDAOImpl();
		/**
		 * 查询所有的学生对象*/
		for(Student student:dao.queryAllStudent()){//遍历student对象
			System.out.println(student);
		}
		
		/**
		 * 查询指定id的学生对象
		Student student=dao.queryStudentById(1);
		System.out.println(student);
		//以上两行代码可缩写为：
		System.out.println(dao.queryStudentById(1));
		*/
		
		/**
		 * 插入学生对象数据
		Student student=new Student();
		student.setSid(3);
		student.setSname("小明");
		student.setMajor("应用化学");
		student.setBirth(Date.valueOf("2013-09-09"));
		student.setScore(88);
		dao.addStudent(student);
		*/
		
		/**
		 * 删除指定id的学生数据
		dao.deleteStudentById(1);
		*/
		
		/**
		 * 修改数据对象
		
		Student student=new Student();
		student.setSid(3);
		student.setSname("朱小明");
		student.setMajor("嵌入式开发");
		student.setBirth(Date.valueOf("2013-09-09"));
		student.setScore(68);
		dao.updateStudentById(student);
		 */
		
		/**
		 * 模糊查询
		 
		for(Student student:dao.queryStudentByName("t")){
			System.out.println(student);
		}
		*/
	}
}
